@@ -1,11 +1,11 @@
 c
 c   TTR: Technical Trading Rules
 c
-c   Copyright (C) 2007-2012  Joshua M. Ulrich
+c   Copyright (C) 2007-2013  Joshua M. Ulrich
 c
 c   This program is free software: you can redistribute it and/or modify
 c   it under the terms of the GNU General Public License as published by
-c   the Free Software Foundation, either version 3 of the License, or
+c   the Free Software Foundation, either version 2 of the License, or
 c   (at your option) any later version.
 c
 c   This program is distributed in the hope that it will be useful,
@@ -170,7 +170,7 @@ c
 
       do 10 i=n+1,lia
 
-        loc = DINT(i-(lag))
+        loc = INT(i-(lag))
         oa(i) = ratio * ( 2*ia(i) - (ia(loc)*(1-wt) + ia(loc+1)*wt ) )
      C         + ( 1 - ratio ) * oa(i-1)
 
